@@ -16,7 +16,7 @@ package Debian::Control::FromCPAN;
 use strict;
 use warnings;
 
-our $VERSION = '0.109';
+our $VERSION = '0.113';
 
 use Carp qw(croak);
 
@@ -171,7 +171,7 @@ sub discover_dependencies {
                         . "Automatic find of" 
                         . " dependencies failed. You may want to \n"
                         . "retry using the '--[b]depends[i]' options\n"
-                        . "or just fill the dependency fields in debian/rules"
+                        . "or just fill the dependency fields in debian/control"
                         . " by hand\n";
 
                         return;
@@ -199,12 +199,22 @@ sub discover_dependencies {
                 . join( ", ", @$debs ) . "\n";
         }
         $bin->Depends->add(@$debs);
+
+        # add runtime dependencies to Build-Depends{,-Indep} as well,
+        # as they are most likely needed for tests, but mark
+        # them as '!<nocheck>' like the test dependencies
+        my $r_debs = Debian::Dependencies->new($debs);
+        foreach (@$r_debs) {
+            $_->{profile} = '!nocheck' unless is_core_perl_package($_->{pkg});
+        }
+
         if ( $bin->Architecture eq 'all' ) {
-            $src->Build_Depends_Indep->add(@$debs);
+            $src->Build_Depends_Indep->add(@$r_debs);
         }
         else {
-            $src->Build_Depends->add(@$debs);
+            $src->Build_Depends->add(@$r_debs);
         }
+
         if ($install_deps) {
             foreach my $deb (@$debs) {
                 _install_deb($deb->pkg) unless grep {$deb} @$missing;
@@ -215,33 +225,63 @@ sub discover_dependencies {
     # build-time
     my ( $b_debs, $b_missing ) = $self->find_debs_for_modules(
         {   %{ $deps->{build_requires}     || {} },
-            %{ $deps->{test_requires}      || {} },
             %{ $deps->{configure_requires} || {} }
         },
         $apt_contents,
         $verbose,
         $dpkg_available,
     );
+    push @$missing, @$b_missing;
 
-    if (@$b_debs) {
+    # still build-time but test_requires only
+    my ( $t_debs, $t_missing ) = $self->find_debs_for_modules(
+        {   %{ $deps->{test_requires} || {} }
+        },
+        $apt_contents,
+        $verbose,
+        $dpkg_available,
+    );
+    push @$missing, @$t_missing;
+
+    # add <!nocheck> profile to test dependencies
+    foreach (@$t_debs) {
+        $_->{profile} = '!nocheck' unless is_core_perl_package($_->{pkg});
+    }
+
+    # HACK
+    # and to new as well as existing (on refresh)
+    # build dependencies called libtest-*
+    foreach ( @$b_debs, @{$src->Build_Depends}, @{$src->Build_Depends_Indep} ) {
+        $_->{profile} = '!nocheck' if $_->{pkg} =~ /^libtest-/;
+    }
+
+    if (@$b_debs || @$t_debs) {
         if ($verbose) {
             print "\n";
-            print "Needs the following debian packages during building: "
-                . join( ", ", @$b_debs ) . "\n";
+            print "Needs the following debian packages during building and testing: "
+                . join( ", ", @$b_debs, @$t_debs ) . "\n";
         }
         if ( $self->is_arch_dep ) {
             $src->Build_Depends->add(@$b_debs);
+            $src->Build_Depends->add(@$t_debs);
         }
         else {
             $src->Build_Depends_Indep->add(@$b_debs);
+            $src->Build_Depends_Indep->add(@$t_debs);
         }
-        if ($install_build_deps || $install_deps) {
-            _install_deb($_->pkg)
-                foreach @$b_debs;
+        if ( $install_build_deps || $install_deps ) {
+            _install_deb( $_->pkg ) foreach ( @$b_debs, @$t_debs );
         }
     }
 
-    push @$missing, @$b_missing;
+    # s/perl/perl:native/ in Build-Depends
+    if ( $self->is_arch_dep ) {
+        my ($perl) = $src->Build_Depends->remove('perl');
+        if ($perl) {
+            $perl->{pkg} = 'perl:native';
+            $src->Build_Depends->add($perl);
+        }
+    }
 
     if (@$missing) {
         my ($missing_debs_str);
@@ -497,7 +537,7 @@ sub prune_simple_perl_dep {
         if $dep->pkg eq 'perl-base' and $unversioned;
 
     # perl is needed in build-dependencies (see Policy 4.2)
-    return $dep if $dep->pkg eq 'perl' and $build;
+    return $dep if $dep->pkg =~ '^perl(:native)?$' and $build;
 
     # unversioned perl non-build-dependency is redundant, because it will be
     # covered by ${perl:Depends}
@@ -546,7 +586,7 @@ sub prune_perl_deps {
     my $self = shift;
 
     # remove build-depending on ancient perl versions
-    for my $perl ( qw( perl perl-base perl-modules ) ) {
+    for my $perl ( qw( perl perl-base perl-modules perl:native ) ) {
         for ( qw( Build_Depends Build_Depends_Indep ) ) {
             my @ess = $self->source->$_->remove($perl);
             # put back non-redundant ones (possibly modified)
@@ -559,7 +599,7 @@ sub prune_perl_deps {
     }
 
     # remove depending on ancient perl versions
-    for my $perl ( qw( perl perl-base perl-modules ) ) {
+    for my $perl ( qw( perl perl-base perl-modules perl:native ) ) {
         for my $pkg ( $self->binary_tie->Values ) {
             for my $rel ( qw(Depends Recommends Suggests) ) {
                 my @ess = $pkg->$rel->remove($perl);
@@ -608,7 +648,7 @@ sub module_name_to_pkg_name {
 
 Copyright (C) 2009, 2010, 2012 Damyan Ivanov L<dmn@debian.org>
 
-Copyright (C) 2019 gregor herrmann L<gregoa@debian.org>
+Copyright (C) 2019, 2020 gregor herrmann L<gregoa@debian.org>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 2 as published by the Free
