@@ -25,7 +25,7 @@ require v5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.109';
+our $VERSION = '0.113';
 
 use base qw( Class::Accessor Tie::IxHash );
 
@@ -262,7 +262,7 @@ field.
 sub looks_like_an_x_field {
     my ( $self, $field ) = @_;
 
-    return $field =~ /^X[SBC]?(?:_[A-Z][A-Za-z0-9]*)+$/;
+    return $field =~ /^X[SBC]*(?:_[A-Z][A-Za-z0-9]*)+$/;
 }
 
 =item get($field)
@@ -387,6 +387,8 @@ sub as_string
 
 Copyright (C) 2009, 2017 Damyan Ivanov L<dmn@debian.org>
 
+Copyright (C) 2020 gregor herrmann L<gregoa@debian.org>
+
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 2 as published by the Free
 Software Foundation.
