@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.109';
+our $VERSION = '0.113';
 
 use feature 'switch';
 
@@ -892,7 +892,9 @@ sub create_rules {
 
     $self->backup_file($file);
 
-    my $rulesname = 'rules.dh.tiny';
+    my $arch = $self->control->binary_tie->Values(0)->Architecture;
+    my $rulesname
+        = ( $arch eq 'all' ? 'rules.dh.tiny.all' : 'rules.dh.tiny.any' );
 
     for my $source (
         catfile( $self->cfg->home_dir, $rulesname ),
@@ -1473,7 +1475,9 @@ sub discover_utility_deps {
         $build_deps_indep->add('perl');
     }
     else {
-        $build_deps->add('perl');
+        $build_deps->remove('perl');
+        $build_deps->add('perl:native');
+        $build_deps->add('perl-xs-dev');
     }
     $build_deps->add( Debian::Dependency->new( 'debhelper-compat', '=', $debhelper_version ) );
 
@@ -1516,7 +1520,7 @@ sub discover_utility_deps {
         my ($mbt)  = $build_deps_indep->remove('libmodule-build-tiny-perl');
         my ($mbup) = $build_deps_indep->remove('libmodule-build-using-pkgconfig-perl');
         my ($perl) = $build_deps_indep->remove('perl');
-        $perl ||= 'perl';
+        $perl ||= ( $architecture eq 'all' ? 'perl' : 'perl:native' );
         $self->explained_dependency( 'Module::Build', $build_deps,
             "$mb" ) if $mb;
         $self->explained_dependency( 'Module::Build::Tiny', $build_deps,
@@ -1658,6 +1662,10 @@ sub create_upstream_metadata {
                 $upstream{"Repository-Browse"} = "https://$domain$path";
             }
         }
+    } else {
+        # we don't care to write debian/upstream/metadata
+        # if we don't have a Repository
+        return;
     }
 
     foreach ( keys %upstream ) {
@@ -1740,7 +1748,7 @@ sub _file_w {
 
 =item Copyright (C) 2006 Frank Lichtenheld <djpig@debian.org>
 
-=item Copyright (C) 2007-2019 gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2007-2020 gregor herrmann <gregoa@debian.org>
 
 =item Copyright (C) 2007-2013 Damyan Ivanov <dmn@debian.org>
 
