@@ -2,7 +2,7 @@ package DhMakePerl::Command::make;
 
 use warnings;
 use strict;
-our $VERSION = '0.109';
+our $VERSION = '0.113';
 use 5.010;    # we use smart matching
 
 use base 'DhMakePerl::Command::Packaging';
@@ -135,6 +135,7 @@ sub execute {
     my $src = $self->control->source;
 
     $src->Testsuite('autopkgtest-pkg-perl') if $self->cfg->{pkg_perl};
+    $src->Rules_Requires_Root('no');
 
     my @missing = $self->discover_dependencies;
 
@@ -183,17 +184,7 @@ sub execute {
     $src->Homepage( $self->upsurl );
     if ( $self->cfg->pkg_perl ) {
         my $vcs = lc( $self->cfg->vcs );
-        if ( $vcs eq 'svn' ) {
-            $self->control->source->Vcs_Svn(
-                sprintf( "svn://svn.debian.org/pkg-perl/trunk/%s/",
-                    $self->pkgname )
-            );
-            $self->control->source->Vcs_Browser(
-                sprintf( "http://anonscm.debian.org/viewvc/pkg-perl/trunk/%s/",
-                    $self->pkgname )
-            );
-        }
-        elsif ( $vcs eq 'git' ) {
+        if ( $vcs eq 'git' ) {
             $self->control->source->Vcs_Git(
                 sprintf( "https://salsa.debian.org/perl-team/modules/packages/%s.git",
                     $self->pkgname )
@@ -453,10 +444,10 @@ sub install_package {
         $archspec );
 
     my $deb = $self->main_dir . "/../$debname";
-    my $dpkg_cmd = "dpkg -i $deb";
-    $dpkg_cmd = "sudo $dpkg_cmd" if $>;
-    $self->info("Running '$dpkg_cmd'...");
-    system($dpkg_cmd) == 0
+    my $install_cmd = "apt-get install $deb";
+    $install_cmd = "sudo $install_cmd" if $>;
+    $self->info("Running '$install_cmd'...");
+    system($install_cmd) == 0
         || die "Cannot install package $deb\n";
 }
 
@@ -880,7 +871,7 @@ You can also look for information at:
 
 =over 4
 
-=item * Debian Bugtracking System
+=item * Debian Bug Tracking System
 
 L<https://bugs.debian.org/dh-make-perl>
 
@@ -902,7 +893,7 @@ L<https://bugs.debian.org/dh-make-perl>
 
 =item Copyright (C) 2006 Frank Lichtenheld <djpig@debian.org>
 
-=item Copyright (C) 2007-2019 Gregor Herrmann <gregoa@debian.org>
+=item Copyright (C) 2007-2020 gregor herrmann <gregoa@debian.org>
 
 =item Copyright (C) 2007,2008,2009,2010,2011,2012,2015 Damyan Ivanov <dmn@debian.org>
 
